==> xlr-server-24.3.0-rc.1-sources.jar: com/xebialabs/xlrelease/server/jetty/JettyServerListener.scala <==
package com.xebialabs.xlrelease.server.jetty

import com.xebialabs.deployit.engine.spi.event.SystemStartedEvent
import com.xebialabs.deployit.event.EventBusHolder
import com.xebialabs.deployit.{ServerConfiguration, ServerState}
import com.xebialabs.xlrelease.XLReleaseBootstrapper
import grizzled.slf4j.Logging
import org.springframework.boot.context.event.{ApplicationFailedEvent, ApplicationReadyEvent}
import org.springframework.context.event.EventListener

import java.lang.System.err

class JettyServerListener(val serverConfiguration: ServerConfiguration) extends Logging {
  final private val serverState = ServerState.getInstance

  @EventListener
  def onApplicationReadyEvent(event: ApplicationReadyEvent): Unit = {
    EventBusHolder.register(serverState)
    EventBusHolder.publish(new SystemStartedEvent)

    logger.info(s"${XLReleaseBootstrapper.PRODUCT_DIGITALAI} has started.")
    logger.info(s"You can now point your browser to ${serverConfiguration.getServerUrl}\n")
  }

  @EventListener
  def onApplicationFailedEvent(event: ApplicationFailedEvent): Unit = {
    val displayMsg = String.format("%s Startup failed: %s%n", XLReleaseBootstrapper.PRODUCT_DIGITALAI, event.getException.getMessage)
    err.println()
    err.println("################################################################################")
    err.println()
    err.println(displayMsg)
    err.println()
    err.println("################################################################################")
    err.println()
  }

}

==> xlr-server-25.1.0-211.113-sources.jar: com/xebialabs/xlrelease/server/jetty/JettyServerListener.scala <==
package com.xebialabs.xlrelease.server.jetty

import com.xebialabs.deployit.engine.spi.event.SystemStartedEvent
import com.xebialabs.deployit.event.EventBusHolder
import com.xebialabs.deployit.{ServerConfiguration, ServerState}
import com.xebialabs.xlrelease.XLReleaseBootstrapper
import grizzled.slf4j.Logging
import org.springframework.boot.context.event.{ApplicationFailedEvent, ApplicationReadyEvent}
import org.springframework.context.event.EventListener

import java.lang.System.err

class JettyServerListener(val serverConfiguration: ServerConfiguration) extends Logging {
  final private val serverState = ServerState.getInstance

  @EventListener
  def onApplicationReadyEvent(event: ApplicationReadyEvent): Unit = {
    EventBusHolder.register(serverState)
    EventBusHolder.publish(new SystemStartedEvent)
    //TODO S-114524 Implement more sophisticated logic to determine if the node is up and ready to accept customer traffic.
    //Currently this event firing means that you can open the server URL in the browser and see the login page.
    //However, in the clustered environment pekko cluster is not formed yet and actor system is not ready, which leads application getting stuck at login page.
    logger.info(s"${XLReleaseBootstrapper.PRODUCT_DIGITALAI} has started.")
    logger.info(s"You can now point your browser to ${serverConfiguration.getServerUrl}\n")
  }

  @EventListener
  def onApplicationFailedEvent(event: ApplicationFailedEvent): Unit = {
    val displayMsg = String.format("%s Startup failed: %s%n", XLReleaseBootstrapper.PRODUCT_DIGITALAI, event.getException.getMessage)
    err.println()
    err.println("################################################################################")
    err.println()
    err.println(displayMsg)
    err.println()
    err.println("################################################################################")
    err.println()
  }

}
